#include <avr/io.h>
#include <avr/interrupt.h>

int main(void)
{
    uint8_t akku=0;
    uint8_t zahl=3;
    uint8_t status_register; //Merker fr Interrupt-Status
    uint16_t adresse = 1022;

    DDRC = 0b11111111;
    DDRB &= 0b11111100;    

    //Interrupts allgemein aktivieren:
    sei();

    //Zuletzt geschriebene Zahl auslesen und anzeigen:
    //Auszulesende Speicheradresse eintragen:
    EEAR = adresse;
    //Lesevorgang auslsen:
    EECR |= (1<<EERE);            
    PORTC = EEDR; //gespeicherte Zahl anzeigen.

    while(true)
    {
        akku = PINB;

        if( (akku & 0b00000001) > 0 ) //PB0, schreiben
        {
            //Warten, bis Taster wieder losgelassen wird, um kein Mehrfachschreiben auszulsen:
            while( (akku & 0b00000001) > 0 )
                akku = PINB;

            //Statusregister zwischenspeichern:
            status_register = SREG;
            //Interrupts ausschalten:
            cli();

            //Adresse eintragen:
            EEAR = adresse; //EEARH und EEARL werden in C als 2Byte-Register EEAR dargestellt.

            //Zahl eintragen:
            EEDR = zahl;

            //Schreibstatus auf 1 setzen, da sonst undefiniert.
            EECR |= (1<<EEMWE);
            //Schreibvorgang auslsen:
            EECR |= (1<<EEWE);            

            //Abwarten, bis EEWE auf Null abfllt, also der Schreibvorgang abgeschlossen ist:
            while(EECR & (1<<EEWE));

            //Statusregister fr Interrupts wieder zurck schreiben:
            SREG=status_register;

            //Interrupts wieder zulassen:
            sei();

            //Anzeigen, dass Schreibvorgang abgeschlossen ist:
            PORTC = 1;

            //Zahl inkrementieren fr nchsten Schreibvorgang:
            zahl++;
        }

        if( (akku & 0b00000010) > 0 ) //PB1, lesen
        {
            while( (akku & 0b00000010) > 0 )
                akku = PINB;

            //Auszulesende Speicheradresse eintragen:
            EEAR = adresse;
            //Lesevorgang auslsen:
            EECR |= (1<<EERE);            
            PORTC = EEDR; //gespeicherte Zahl anzeigen.
        }
    }
    return 0;
}
